"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapColumn = void 0;
const tslib_1 = require("tslib");
const lodash_1 = require("lodash");
const config_1 = tslib_1.__importDefault(require("./config"));
function mapColumn(Table, enumTypes) {
    return lodash_1.mapValues(Table, (column) => {
        const name = column.udtName;
        const tsType = findTsType(name);
        const enumType = findEnumType(name, enumTypes);
        return {
            ...column,
            tsType: tsType !== null && tsType !== void 0 ? tsType : enumType,
        };
    });
}
exports.mapColumn = mapColumn;
function findEnumType(udtName, enumTypes) {
    var _a;
    const enumType = enumTypes[udtName];
    return (_a = enumType === null || enumType === void 0 ? void 0 : enumType.map((s) => `'${s}'`).join(' | ')) !== null && _a !== void 0 ? _a : 'any';
}
function findTsType(udtName) {
    switch (udtName) {
        case 'char':
        case 'varchar':
        case 'text':
        case 'tinytext':
        case 'mediumtext':
        case 'longtext':
        case 'time':
        case 'geometry':
        case 'set':
        case 'enum':
            return 'string';
        case 'integer':
        case 'int':
        case 'smallint':
        case 'mediumint':
        case 'bigint':
        case 'double':
        case 'decimal':
        case 'numeric':
        case 'float':
        case 'year':
            return 'number';
        case 'json':
            return 'JSONValue';
        case 'date':
        case 'datetime':
        case 'timestamp':
            return 'Date';
        case 'tinyblob':
        case 'mediumblob':
        case 'longblob':
        case 'blob':
        case 'binary':
        case 'varbinary':
        case 'bit':
            return config_1.default.binaryAsBuffer ? 'Buffer' : 'string';
        case 'tinyint':
            return config_1.default.tinyIntAsBoolean ? 'boolean' : 'number';
        default:
            return null;
    }
}
//# sourceMappingURL=column-map.js.map