"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tableToTS = void 0;
const tslib_1 = require("tslib");
const camelcase_1 = tslib_1.__importDefault(require("camelcase"));
const config_1 = tslib_1.__importDefault(require("./config"));
function camelize(s) {
    return camelcase_1.default(s, { pascalCase: true });
}
function normalize(name) {
    const reservedKeywords = ['string', 'number', 'package'];
    let safename = name;
    if (reservedKeywords.includes(name)) {
        safename = name + '_';
    }
    return safename;
}
function tableToTS(name, prefix, table) {
    const members = (withDefaults) => Object.keys(table).map((column) => {
        var _a;
        const type = table[column].tsType;
        const nullable = table[column].nullable;
        const nullablestr = !nullable || (!withDefaults && config_1.default.nullAsUndefined) ? '' : '| null';
        const hasDefault = table[column].hasDefault;
        const defaultValue = (_a = table[column].defaultValue) !== null && _a !== void 0 ? _a : '';
        const defaultComment = withDefaults && hasDefault ? `Defaults to: ${defaultValue}` : '';
        const comment = `${table[column].comment} ${defaultComment}`;
        const tsComment = comment.trim().length > 0 ? `\n/** ${comment} */\n` : '';
        const isOptional = withDefaults ? nullable || hasDefault : nullable;
        return `${tsComment}${normalize(column)}${(withDefaults && isOptional) || (isOptional && (config_1.default.nullAsUndefined || config_1.default.nullPlusUndefined)) ? '?' : ''}: ${type}${nullablestr}\n`;
    });
    const tableName = (prefix || '') + camelize(normalize(name));
    return `
    /**
     * Exposes all fields present in ${name} as a typescript
     * type. 
     * This is especially useful for SELECT * FROM
    */
    export ${config_1.default.outputAsTypes ? 'type' : 'interface'} ${tableName} ${config_1.default.outputAsTypes ? '=' : ''} {
    ${members(false)}
    }

    /**
     * Exposes the same fields as ${tableName},
     * but makes every field containing a DEFAULT value optional.
     *
     * This is especially useful when generating inserts, as you
     * should be able to ommit these fields if you'd like
    */
    export ${config_1.default.outputAsTypes ? 'type' : 'interface'} ${tableName}WithDefaults ${config_1.default.outputAsTypes ? '=' : ''} {
    ${members(true)}
    }
  `.trim();
}
exports.tableToTS = tableToTS;
//# sourceMappingURL=generator.js.map