#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const table_1 = require("./table");
const meow_1 = tslib_1.__importDefault(require("meow"));
const config_1 = tslib_1.__importDefault(require("./config"));
const cli = meow_1.default(`
	Usage
	  $ mysql8-schema-ts <input>

	Options
    --table, -t               Table name
    --prefix, -p              Prefix to add to table names
    --tinyIntAsBoolean, -b    Treat TinyInt as Boolean
    --binaryAsBuffer, -B      Treat Binary as Buffer
    --nullAsUndefined, -u     Treat null as undefined   
    --nullPlusUndefined, -p   Treat as null and undefined
    --outputAsTypes           Output types instead of interfaces

	Examples
	  $ mysql8-schema-ts --prefix SQL
`, {
    flags: {
        table: {
            type: 'string',
            alias: 't',
            default: '',
        },
        prefix: {
            type: 'string',
            alias: 'p',
            default: '',
        },
        tinyIntAsBoolean: {
            type: 'boolean',
            alias: 'b',
            default: false,
        },
        binaryAsBuffer: {
            type: 'boolean',
            alias: 'B',
            default: false,
        },
        nullAsUndefined: {
            type: 'boolean',
            alias: 'u',
            default: false,
        },
        nullPlusUndefined: {
            type: 'boolean',
            alias: 'p',
            default: false,
        },
        outputAsTypes: {
            type: 'boolean',
            default: false,
        },
    },
});
const db = cli.input[0];
const { table, prefix, tinyIntAsBoolean, binaryAsBuffer, nullAsUndefined, nullPlusUndefined, outputAsTypes } = cli.flags;
async function main() {
    if (!db) {
        cli.showHelp();
    }
    config_1.default.binaryAsBuffer = binaryAsBuffer;
    config_1.default.tinyIntAsBoolean = tinyIntAsBoolean;
    config_1.default.nullAsUndefined = nullAsUndefined;
    config_1.default.nullPlusUndefined = nullPlusUndefined;
    config_1.default.outputAsTypes = outputAsTypes;
    if (cli.flags.table) {
        return table_1.inferTable(db, table, prefix);
    }
    return table_1.inferSchema(db, prefix);
}
main()
    .then((code) => {
    process.stdout.write(code);
    process.exit(0);
})
    .catch((err) => {
    console.error(err);
    process.exit(1);
});
//# sourceMappingURL=index.js.map