"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.inferSchemaObject = exports.inferTableObject = exports.inferSchema = exports.inferTable = void 0;
const tslib_1 = require("tslib");
const generator_1 = require("./generator");
const mysql_client_1 = require("./mysql-client");
const prettier_1 = tslib_1.__importDefault(require("prettier"));
const moment_1 = tslib_1.__importDefault(require("moment"));
const pkg_json_1 = tslib_1.__importDefault(require("./pkg.json"));
function pretty(code) {
    return prettier_1.default.format(code, {
        parser: 'typescript',
        semi: false,
        singleQuote: true,
    });
}
const JSONHeader = `
export type JSONPrimitive = string | number | boolean | null;
export type JSONValue = JSONPrimitive | JSONObject | JSONArray;
export type JSONObject = { [member: string]: JSONValue };
export type JSONArray = Array<JSONValue>
`;
const header = (includesJSON) => `
/**
 * AUTO-GENERATED FILE @ ${moment_1.default().format('YYYY-MM-DD')} - DO NOT EDIT!
 *
 * This file was automatically generated by ${pkg_json_1.default.name} ${pkg_json_1.default.version}
*/

${includesJSON ? JSONHeader : ''}
`;
async function inferTable(connectionString, table, prefix = '') {
    const db = new mysql_client_1.MySQL(connectionString);
    const code = generator_1.tableToTS(table, prefix, await db.table(table));
    const fullCode = `
    ${await header(code.includes('JSON'))}
    ${code}
  `;
    return pretty(fullCode);
}
exports.inferTable = inferTable;
async function inferSchema(connectionString, prefix = '') {
    const db = new mysql_client_1.MySQL(connectionString);
    const tables = await db.allTables();
    const types = tables.map((table) => generator_1.tableToTS(table.name, prefix, table.table));
    const code = [await header(types.some((i) => i.includes('JSON'))), ...types].join('\n\n');
    return pretty(code);
}
exports.inferSchema = inferSchema;
async function inferTableObject(connectionString, table) {
    const db = new mysql_client_1.MySQL(connectionString);
    return db.table(table);
}
exports.inferTableObject = inferTableObject;
async function inferSchemaObject(connectionString) {
    const db = new mysql_client_1.MySQL(connectionString);
    const tables = await db.allTables();
    return tables;
}
exports.inferSchemaObject = inferSchemaObject;
//# sourceMappingURL=table.js.map